Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1234)

Unified Diff: content/browser/resources/media/webrtc_internals.js

Issue 1272223003: Implement writing mic audio input data to file for debugging purposes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/resources/media/dump_creator.js ('k') | content/content_browser.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/resources/media/webrtc_internals.js
diff --git a/content/browser/resources/media/webrtc_internals.js b/content/browser/resources/media/webrtc_internals.js
index 5654fe9a47782890e4423af328ae75f51aef7ccc..5b3bb0d4d6f4b08088d2b57c058bad9baaeb5bb1 100644
--- a/content/browser/resources/media/webrtc_internals.js
+++ b/content/browser/resources/media/webrtc_internals.js
@@ -323,17 +323,17 @@ function removeGetUserMediaForRenderer(data) {
/**
* Notification that the AEC recording file selection dialog was cancelled,
* i.e. AEC has not been enabled.
*/
-function aecRecordingFileSelectionCancelled() {
- dumpCreator.disableAecRecording();
+function audioDebugRecordingsFileSelectionCancelled() {
+ dumpCreator.disableAudioDebugRecordings();
}
/**
* Set
*/
-function enableAecRecording() {
- dumpCreator.enableAecRecording();
+function enableAudioDebugRecordings() {
+ dumpCreator.enableAudioDebugRecordings();
}
« no previous file with comments | « content/browser/resources/media/dump_creator.js ('k') | content/content_browser.gypi » ('j') | no next file with comments »
@@ -323,17 +323,17 @@ function removeGetUserMediaForRenderer(data) {
/**
- * Notification that the AEC recording file selection dialog was cancelled,
- * i.e. AEC has not been enabled.
+ * Notification that the audio debug recordings file selection dialog was
+ * cancelled, i.e. recordings have not been enabled.
*/

Powered by Google App Engine
This is Rietveld 408576698